# NotePlan Plugin Launcher

A cross-platform Python application for launching NotePlan plugin commands with enhanced support for different NotePlan installations.

## Features

- Browse and search all installed NotePlan plugins
- Launch plugin commands with a single click
- Track recently used commands
- Save your favorite commands for quick access
- Hide plugins you don't use regularly from the banner
- Automatic detection of NotePlan installation (Setapp or direct download)
- Cross-platform compatibility (primarily for macOS, with Windows and Linux support for future NotePlan versions)

## Installation

1. Make sure you have Python 3.6+ installed
2. Install required packages:
   ```
   pip install -r requirements.txt
   ```

## Usage

### Running the Application

The easiest way to run the application is to use the provided shell script:

```
./run.sh
```

Alternatively, you can run it directly with Python:

```
python app.py
```

### Debugging NotePlan Plugin Paths

To debug plugin paths (useful when NotePlan isn't being detected):

```
./run.sh --debug-paths
```

or

```
python app.py --debug-paths
```

This will show all potential NotePlan plugin paths and which one the application is using.

## Interface

The application shows a banner with emoji icons for all your installed NotePlan plugins:

- **Favorites**: Access your favorite commands with the ❤️ button
- **Plugin Emojis**: Click on any plugin emoji to see its commands
- **Show/Hide Plugins**: Choose which plugins appear in the banner
- **Theme Toggle**: Switch between light and dark modes

## Supported NotePlan Installations

The application automatically detects and works with:
- NotePlan Setapp version
- NotePlan Mac App Store version
- NotePlan direct download version
- Both sandboxed and non-sandboxed installations

## Requirements

- Python 3.6+
- PyQt6
- NotePlan installed (primarily on macOS - Windows/Linux support is preliminary)

## Path Handling

The application looks for NotePlan plugins in several locations:

1. Sandboxed Setapp: `~/Library/Containers/co.noteplan.NotePlan-setapp/Data/Library/Application Support/co.noteplan.NotePlan-setapp/Plugins`
2. Sandboxed regular: `~/Library/Containers/co.noteplan.NotePlan/Data/Library/Application Support/co.noteplan.NotePlan/Plugins`
3. Non-Setapp direct: `~/Library/Application Support/co.noteplan.NotePlan/Plugins`
4. Older versions: `~/Library/Application Support/NotePlan/Plugins`
5. Other containers matching the NotePlan pattern